# Hahmlet Fonts Project

## Description

The Hahmlet typeface family is designer for the Latin and Hangeul scripts.

## Designers

* Minjoo Ham (Hangeul)
* Mark Frömberg (Latin Expert)

## License

SIL Open Font License ([OFL.txt](OFL.txt))

